#
# spec file for package cri-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define executable_name crictl

Name:           cri-tools
Version:        1.33.0
Release:        1.1
Summary:        CLI and validation tools for Kubelet Container Runtime Interface
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/kubernetes-sigs/cri-tools
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
Source11:       crictl.yaml
BuildRequires:  go-go-md2man
BuildRequires:  golang(API) >= 1.24
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh

%description
cri-tools provides a series of debugging and validation tools for
Kubelet CRI, which includes:

- crictl: CLI for kubelet CRI
- critest: validation test suites for kubelet CRI

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build -o bin/%{executable_name} ./cmd/%{executable_name}
go test -o bin/critest -c ./cmd/critest

# compile the manpage
go-md2man -in docs/%{executable_name}.md -out docs/%{executable_name}.1

%install
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}
install -D -m 0755 bin/critest %{buildroot}/%{_bindir}/critest

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

install -d %{buildroot}/%{_mandir}/man1
install -D -m 0644 docs/%{executable_name}.1 %{buildroot}/%{_mandir}/man1/
install -D -m 0644 %{SOURCE11} %{buildroot}/%{_sysconfdir}/crictl.yaml

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}
%{_bindir}/critest
%config(noreplace) %{_sysconfdir}/crictl.yaml

%{_mandir}/man1/*

%{_datarootdir}/bash-completion/completions/%{executable_name}
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Sat Jun  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.33.0:
  https://github.com/kubernetes-sigs/cri-tools/releases/tag/v1.33.0
  * Feature
  - Add metricdescs subcommand for ListMetricDescriptors API (#1815, @bitoku)
  - Added crictl update --oom-score-adj flag. (#1781, @saschagrunert)
  - KEP-3619: "crictl info" now shows "RuntimeFeatures" object(in ".features" field) (#1772, @everpeace)
  - crictl logs now is able to fetch a specific log stream of a container with the introducted --stream flag. (#1724, @knight42)
  * Documentation
  - Generated man files using go-md2man v2. (#1770, @saschagrunert)
  * Bug or Regression
  - Added --all flag to crictl inspect to allow listing exited containers.
  - Fixed --image filter flag for crictl inspect and exec. (#1752, @saschagrunert)
  * Dependencies added
  - github.com/GoogleCloudPlatform/opentelemetry-operations-go/detectors/gcp: v1.26.0
  - github.com/envoyproxy/go-control-plane/envoy: v1.32.4
  - github.com/envoyproxy/go-control-plane/ratelimit: v0.1.0
  - github.com/go-jose/go-jose/v4: v4.0.4
  - github.com/klauspost/compress: v1.18.0
  - github.com/kylelemons/godebug: v1.1.0
  - github.com/prashantv/gostub: v1.1.0
  - github.com/spiffe/go-spiffe/v2: v2.5.0
  - github.com/zeebo/errs: v1.4.0
  - go.opentelemetry.io/auto/sdk: v1.1.0
  - go.opentelemetry.io/contrib/detectors/gcp: v1.34.0
  - go.opentelemetry.io/otel/sdk/metric: v1.34.0
  - go.uber.org/automaxprocs: v1.6.0
  - sigs.k8s.io/randfill: v1.0.0
  * Dependencies changed
  - cel.dev/expr: v0.16.1 → v0.20.0
  - cloud.google.com/go/compute/metadata: v0.5.0 → v0.6.0
  - github.com/Azure/go-ansiterm: 306776e → faa5f7b
  - github.com/cncf/xds/go: b4127c9 → 2f00578
  - github.com/docker/docker: v27.3.1+incompatible → v28.1.1+incompatible
  - github.com/envoyproxy/go-control-plane: v0.13.0 → v0.13.4
  - github.com/envoyproxy/protoc-gen-validate: v1.1.0 → v1.2.1
  - github.com/golang/glog: v1.2.2 → v1.2.4
  - github.com/google/btree: v1.0.1 → v1.1.3
  - github.com/google/gnostic-models: v0.6.8 → v0.6.9
  - github.com/google/go-cmp: v0.6.0 → v0.7.0
  - github.com/google/gofuzz: v1.2.0 → v1.0.0
  - github.com/google/pprof: d1b30fe → 27863c8
  - github.com/gorilla/websocket: v1.5.0 → e064f32
  - github.com/grpc-ecosystem/grpc-gateway/v2: v2.23.0 → v2.26.1
  - github.com/invopop/jsonschema: v0.12.0 → v0.13.0
  - github.com/moby/term: v0.5.0 → v0.5.2
  - github.com/onsi/ginkgo/v2: v2.22.0 → v2.23.4
  - github.com/onsi/gomega: v1.36.0 → v1.37.0
  - github.com/opencontainers/selinux: v1.11.1 → v1.12.0
  - github.com/pmezard/go-difflib: 5d4384e → v1.0.0
  - github.com/prometheus/client_golang: v1.19.1 → v1.22.0-rc.0
  - github.com/prometheus/common: v0.55.0 → v0.62.0
  - github.com/stretchr/objx: v0.1.0 → v0.5.2
  - github.com/stretchr/testify: v1.9.0 → v1.10.0
  - github.com/urfave/cli/v2: v2.27.5 → v2.27.6
  - go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc: v0.53.0 → v0.58.0
  - go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp: v0.53.0 → v0.58.0
  - go.opentelemetry.io/otel/exporters/otlp/otlptrace/otlptracegrpc: v1.32.0 → v1.35.0
  - go.opentelemetry.io/otel/exporters/otlp/otlptrace: v1.32.0 → v1.35.0
  - go.opentelemetry.io/otel/metric: v1.32.0 → v1.35.0
  - go.opentelemetry.io/otel/sdk: v1.32.0 → v1.35.0
  - go.opentelemetry.io/otel/trace: v1.32.0 → v1.35.0
  - go.opentelemetry.io/otel: v1.32.0 → v1.35.0
  - go.opentelemetry.io/proto/otlp: v1.3.1 → v1.5.0
  - golang.org/x/crypto: v0.28.0 → v0.36.0
  - golang.org/x/mod: v0.21.0 → v0.24.0
  - golang.org/x/net: v0.30.0 → v0.38.0
  - golang.org/x/oauth2: v0.23.0 → v0.27.0
  - golang.org/x/sync: v0.10.0 → v0.13.0
  - golang.org/x/sys: v0.28.0 → v0.32.0
  - golang.org/x/term: v0.27.0 → v0.31.0
  - golang.org/x/text: v0.21.0 → v0.24.0
  - golang.org/x/time: v0.7.0 → v0.9.0
  - golang.org/x/tools: v0.26.0 → v0.31.0
  - google.golang.org/genproto/googleapis/api: dd2ea8e → 56aae31
  - google.golang.org/genproto/googleapis/rpc: dd2ea8e → 56aae31
  - google.golang.org/grpc: v1.68.1 → v1.72.0
  - google.golang.org/protobuf: v1.35.2 → v1.36.6
  - k8s.io/api: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/apimachinery: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/apiserver: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/cli-runtime: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/client-go: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/component-base: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/component-helpers: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/cri-api: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/cri-client: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/kube-openapi: 32ad38e → c8a335a
  - k8s.io/kubectl: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/kubelet: v0.32.0-rc.2 → v0.33.0-rc.0
  - k8s.io/metrics: v0.32.0-rc.2 → v0.33.0-rc.0
  - sigs.k8s.io/kustomize/api: v0.18.0 → v0.19.0
  - sigs.k8s.io/kustomize/kustomize/v5: v5.5.0 → v5.6.0
  - sigs.k8s.io/kustomize/kyaml: v0.18.1 → v0.19.0
  - sigs.k8s.io/structured-merge-diff/v4: v4.4.2 → v4.6.0
  * Dependencies removed
  - github.com/census-instrumentation/opencensus-proto: v0.4.1
  - github.com/go-kit/log: v0.2.1
  - github.com/go-logfmt/logfmt: v0.5.1
  - google.golang.org/appengine: v1.6.7
- refactor '_service' file to use obs_scm
- refactor spec file
* Fri Feb 28 2025 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.32.0:
  * Ref for changelog: https://github.com/kubernetes-sigs/cri-tools/releases/tag/v1.32.0
- update: `%%define project sigs.k8s.io/cri-tools`
- bump: `BuildRequires:  golang(API) >= 1.24`
- update _service file to add `go_modules` service to generate the `vendor.tar.gz`
  * update .spec file to add the vendor tarball as source
* Thu May 19 2022 jkowalczyk@suse.com
- Update to version 1.24.1:
  * Bump github.com/onsi/ginkgo/v2 from 2.1.3 to 2.1.4
  * Bump github.com/opencontainers/runc from 1.1.1 to 1.1.2
  * Remove selinux build tag
  * cmd/critest: fix empty ginkgo flag's value issue
  * Bump github.com/docker/docker
  * Bump github.com/urfave/cli/v2 from 2.5.1 to 2.6.0
  * Switch to ginkgo/v2
* Thu May 19 2022 jkowalczyk@suse.com
- Update to version 1.24.0:
  * Vendor Kubernetes v1.24.0
  * Fixes the incubator project reference
  * update containerd socket in windows
  * Bump github.com/opencontainers/runc from 1.1.0 to 1.1.1
  * Bump github.com/urfave/cli/v2 from 2.4.0 to 2.5.1
  * Bump github.com/opencontainers/selinux from 1.10.0 to 1.10.1
  * Bump github.com/docker/docker
  * Bump github.com/onsi/gomega from 1.18.1 to 1.19.0
  * install CNI on linux
  * Fix setup-gcloud action by referencing `v0`
  * Fix CRI-O tests
  * Add CRICTL_AUTH env var option to crictl pull
  * Make RPCs CRI v1 and v1alpha2 compatible
  * Bump github.com/urfave/cli/v2 from 2.3.0 to 2.4.0
  * Bump github.com/docker/docker
  * Bump google.golang.org/grpc from 1.44.0 to 1.45.0
  * Bump github.com/docker/distribution
  * fix security test case for hostpid
  * fix log info for mount test case
  * fix seccomp test case for arm64
  * Type cast error messages to `string`
  * add annotation for pull
  * Bump github.com/docker/distribution
  * Add `crictl statsp` command
  * Update crictl ps to show pod name and image path
  * Bump github.com/onsi/gomega from 1.18.0 to 1.18.1
  * Add backwards compatiblity to `Version` and `ListContainerStats` RPCs
  * Switch to CRI v1 API
  * Bump google.golang.org/grpc from 1.43.0 to 1.44.0
  * Bump github.com/onsi/gomega from 1.17.0 to 1.18.0
  * Bump github.com/opencontainers/runc from 1.0.3 to 1.1.0
* Wed Mar 16 2022 rbrown@suse.com
- Update to version 1.23.0:
  * Bump docs to v1.23.0
  * Bump github.com/opencontainers/selinux from 1.9.1 to 1.10.0
  * Bump github.com/opencontainers/runc from 1.0.2 to 1.0.3
  * Bump github.com/docker/docker
  * Bump google.golang.org/grpc from 1.42.0 to 1.43.0
  * 1.5.9
  * Use same grpc max message size as Kubelet
  * Add support for cri-dockerd
  * Add support for specifying custom test container images.
  * Fix cri-dockerd CI runs
  * Fix Containerd main branch CI for Windows
  * fix ci for dockershim-critest
  * Update Windows images for ltsc2022
  * images: use k8s-staging-test-infra/gcb-docker-gcloud
  * Bump github.com/onsi/gomega from 1.16.0 to 1.17.0
  * Refactor fish completion
  * Rename bash and zsh completion functions
  * Add zsh compinit tag
  * Bump google.golang.org/grpc from 1.41.0 to 1.42.0
  * Bump github.com/docker/docker
  * Bump github.com/onsi/ginkgo from 1.16.4 to 1.16.5
  * Add release publishing workflow
  * Bump github.com/opencontainers/selinux from 1.8.5 to 1.9.1
  * Add SHA512 sum for release files
  * Bump github.com/docker/docker
  * Bump google.golang.org/grpc from 1.40.0 to 1.41.0
  * Bump sigs.k8s.io/yaml from 1.2.0 to 1.3.0
  * Bump k8s.io/api from 0.22.1 to 0.22.2
  * Bump k8s.io/cri-api from 0.22.1 to 0.22.2
  * Bump k8s.io/apimachinery from 0.22.1 to 0.22.2
  * Bump k8s.io/client-go from 0.22.1 to 0.22.2
  * Bump k8s.io/kubectl from 0.22.1 to 0.22.2
  * Updates E2E test images registry
  * Bump github.com/opencontainers/selinux from 1.8.4 to 1.8.5
  * Switch to go1.17 for CI
  * Bump github.com/opencontainers/runc from 1.0.1 to 1.0.2
  * Added dropping/adding `ALL` capabilities case to critest
  * Bump github.com/onsi/gomega from 1.15.0 to 1.16.0
  * Bump k8s.io/cri-api from 0.22.0 to 0.22.1
  * Bump k8s.io/client-go from 0.22.0 to 0.22.1
  * Bump k8s.io/api from 0.22.0 to 0.22.1
  * Bump k8s.io/apimachinery from 0.22.0 to 0.22.1
  * Bump k8s.io/kubectl from 0.22.0 to 0.22.1
  * Bump google.golang.org/grpc from 1.39.1 to 1.40.0
  * Bump github.com/onsi/gomega from 1.14.0 to 1.15.0
  * Bump github.com/opencontainers/selinux from 1.8.3 to 1.8.4
  * Bump google.golang.org/grpc from 1.39.0 to 1.39.1
* Fri Aug  6 2021 alexandre.vicenzi@suse.com
- Update to version 1.22.0:
  * Bump Kubernetes to v1.22.0
  * Bump k8s.io/api from 0.21.3 to 0.22.0
  * Bump k8s.io/cri-api from 0.21.3 to 0.22.0
  * Bump k8s.io/kubectl from 0.21.3 to 0.22.0
  * Bump k8s.io/apimachinery from 0.21.3 to 0.22.0
  * Bump github.com/docker/docker
  * Bump github.com/opencontainers/selinux from 1.8.2 to 1.8.3
* Fri Aug  6 2021 alexandre.vicenzi@suse.com
- Update to version 1.21.0:
  * Bump README versions to v1.21.0
  * Update dependencies
  * Add dependabot config file
  * Simplify test image build process for user images
  * Move from gcr.io/cri-tools to gcr.io/k8s-staging-cri-tools
  * Fix UID/GID and username values for test images
  * Bump gcb-docker-gcloud image to v20210331-c732583
  * Fix CRI-O master installation in GitHub actions
* Mon Apr 12 2021 alexandre.vicenzi@suse.com
- Update to version 1.21.0:
  * Bump README versions to v1.21.0
  * Update dependencies
  * Add dependabot config file
  * Simplify test image build process for user images
  * Move from gcr.io/cri-tools to gcr.io/k8s-staging-cri-tools
  * Fix UID/GID and username values for test images
  * Bump gcb-docker-gcloud image to v20210331-c732583
  * Fix CRI-O master installation in GitHub actions
* Fri Jan  8 2021 rbrown@suse.com
- Update to version 1.20.0:
  * fix a bug in closure function
  * Trigger prow job
  * Update Kubernetes to v1.20.0
  * Dockershim critest on Windows
  * Fix CRI Test with Windows containerd runtime
  * Add comment to cloud build manifest file
  * Add clarity to docs about default runtimes
  * Add staging build for test user images
  * version 1.17.0 -> 1.19.0 in crictl.md
* Wed Apr  1 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v1.18.0:
  * Main Changes
  * Update Kubernetes to v1.18.0
  * Switch to urfave/cli/v2
  * CRI CLI (crictl)
  * Use ContextDialer to fix build
  * Add go-template option for inspect commands
  * Fix invalid log_path in docs
  * CRI validation testing (critest)
  * Make apparmor failure test more flexible
  * Start container before fetching metrics
  * Cleanup container create test to reduce duplication
  * Add container stats test
* Mon Dec 16 2019 Sascha Grunert <sgrunert@suse.com>
- Update to v1.17.0:
  * crictl
  * Bump cri-tools version in markdown docs
  * Vendor kubernetes v1.17.0
  * Update golang dependencies
  * Print the previous log of the container(just like kubectl)
  * Add rmi --prune command
  * Update README.md to contain latest version hint
  * Download golangci-lint via wget
  * Fix pod and container name filter for JSON/YAML output
  * Fix e2e tests by pinning CRI-O and conmon
  * Fixed Tim St. Clair's username
  * Add fish shell completion support
* Thu Sep 26 2019 Richard Brown <rbrown@suse.com>
- Update to v1.16.1:
  * crictl:
  * Fix empty fields in crictl inspect(p/i) result.
  * Pass pod config when pulling image during container creation.
  * Fix crictl stats panic.
  * critest
  * Skip hostnetwork portforward test on windows.
  * Add hostname test.
* Tue Sep 17 2019 Sascha Grunert <sgrunert@suse.com>
- Update to v1.16.0:
  * crictl:
  * Add container 'run' subcommand.
  * Pull image on container creation.
  * Treat first crictl stats argument as filter ID.
  * Add -a (remove all) option to rmp.
  * Create directory for config file.
  * Add container rm --force, -f and --all, -a flags.
  * Add images aliases image, img.
  * Add --all, -a flag to image removal (rmi).
  * Update Kubernetes vendors to 1.16.0 and add addiontion IPs for Pods.
  * critest:
  * Add registry prefix option.
  * Add test for MaskedPaths and ReadonlyPaths.
  * Switch to multi-arch nonewprivs image.
  * Use arch specific hostnet-nginx image.
  * Use a dedicated image for all reference test.
  * Use IsAppArmorEnabled of Kubernetes instead of local one.
  * Fix exec test timeout issues.
* Thu Jul  4 2019 Michal Jura <mjura@suse.com>
- Update golang(API) requiremnt to 1.12
* Thu Jul  4 2019 Michal Jura <mjura@suse.com>
- Update cri-tools to v1.15.0:
  * Add registry prefix option
  * Revert "Skip test "image status should support all kinds of references" for docker runtime"
  * Upgrade Kuberntes version to v1.15.0
  * Fix typo in parallel
  * Skip test "image status should support all kinds of references" since dockershim doesn't support it
  * Fallback to repo digest name if repoTag is <none>:<none>
  * feature: add display; support live monitoring critool stats
  * Test image status for various references.
  * fix debug in config file
  * Update `rmp` to test for running sandbox
  * Fix logDirectory typo in examples.
  * Search program directory for config as fallback
  * Improve error message for failed to connect
  * Set SelinuxRelabel to true for bind mounts
  * Include gcs bucket release.
  * Use same version as previous example
  * Add `curl` to download example
* Mon Mar 25 2019 Sascha Grunert <sgrunert@suse.com>
- Update cri-tools to v1.14.0:
  * CRI CLI (crictl)
  * Adds imagefsinfo subcommand for CRI ImageFSInfo() method.
  * Adds support to filter containers by image.
  * Fixes a bug when removing multiple containers.
  * Reduces the default connection timeout value.
  * Fixes the exit code for crictl exec.
  * Updated the instructions fro godep.
  * Adds support of -q for crictl info.
  * Adds support of zsh completion.
  * Upgrades kubernetes version to 1.14.
  * CRI validation testing (critest)
  * Adds a benchmark testcase for measuring the time of creating pod and a
    container.
  * Changes streaming tests to omit newlines on echo
  * Adds support of critest for Windows container runtime.
  * Updates test environment to xenial and fixes docker installation.
  * Updates Go version to 1.12.
* Mon Dec 17 2018 Sascha Grunert <sgrunert@suse.com>
- Added `rpmlintrc` to spec file
* Fri Dec 14 2018 Sascha Grunert <sgrunert@suse.com>
- Update cri-tools to v1.13.0:
  * CRI CLI (crictl):
  * Adds --auth options for pull command
  * Fixes URL parsing for exec and attach
  * Upgrades Go version to 1.11.1
  * Enables Windows CI on travis
  * Switches Windows default endpoints to npipe
  * Updates version matrix information for the project
  * Adds container name filter to ps command
  * Adds metadata to filters
  * Prints annotations and labels for inspect command
  * CRI validation testing (critest)
  * Add tests for multiple containers in a pod
  * Adds runtime handler support for critest
  * Adds exec sync timeout test cases
  * Fixes readonly filesystem test cases
- Add `crictl.yaml` to install directory
- Fix build for ppc64
- Require golang >= 1.11
* Tue Nov 13 2018 Valentin Rothberg <vrothberg@suse.com>
- crictl/critest: compile version
- Require golang >= 1.10.
* Tue Oct  2 2018 Valentin Rothberg <vrothberg@suse.com>
- Bump cri-tools to v1.12.0:
  * Properly returns errors when the output format is not supported
  * Show concise image info for crictl ps
  * Fixes crictl ps and crictl pods
  * Adds podID in output of crictl ps
  * Adds sandbox config to image pull
  * Fixes unmarshal issues in crictl inspecti
  * Fixes timeout for grpc dialer
  * Adds new test to critest for privileged container
* Mon Aug 13 2018 vrothberg@suse.com
- Generate and install bash completion for crictl.
- Provide /etc/crictl.yaml config.
  bsc#1104598
* Thu Aug  2 2018 vrothberg@suse.com
- Bump cri-tools to v1.11.1:
  * versioning is now consistent with Kubernetes
  * Fix argument parsing for crictl exec
  * Improved documentation
  * Multi-arch critest tests
  * Filter pods with prefix matching of name and namespace
  * Improve terminal support for exec and attach
* Fri Jun 15 2018 vrothberg@suse.com
- Bump cri-tools to v1.0.0-beta.1 (CRI v1.10.x):
  * crictl: allow short option handling
  * crictl-exec: fix argument parsing
  * Update documentation
  * Kubernetes/CRI 1.10.x compatibility
  * Minor bug fixe
* Tue Jun  5 2018 dcassany@suse.com
- Refactor %%license usage to a simpler form
* Mon Jun  4 2018 dcassany@suse.com
- Make use of %%license macro
* Mon Mar  5 2018 vrothberg@suse.com
- Use cri-tools v1.0.0-alpha.0 to be compatible to cri-o v1.9.x.
* Fri Mar  2 2018 fcastelli@suse.com
- Change buildtime requirement of go-md2man: use go-go-md2man to ensure
  package builds on IBS against sle12sp3. This change won't affect openSUSE
* Wed Feb 14 2018 jengelh@inai.de
- Description shall say what the software does now, not in the
  future.
* Mon Feb 12 2018 vrothberg@suse.com
- Add cri-tools packaging for debugging and validating tools for the Kubelet
  CRI, including the tools crictl and critest.
